permissionUrl = "https://shenmind.com/apiv2/private/upload/permission"

createPredictionUrl = 'https://shenmind.com/apiv2/private/prediction'
queryPredictionUrl = 'https://shenmind.com/apiv2/prediction/outputs'
cancelPredictionUrl = 'https://shenmind.com/apiv2/private/prediction/cancel'
